@@ -19,7 +19,7 @@ predict.coxnet=function(object,newx,s=NULL,type=c("link","response","coefficient
     dimnames(nbeta)=list(NULL,NULL)
     lambda=object$lambda
     lamlist=lambda.interp(lambda,s)
-    nbeta=nbeta[,lamlist$left,drop=FALSE]*lamlist$frac +nbeta[,lamlist$right,drop=FALSE]*(1-lamlist$frac)
+    nbeta=nbeta[,lamlist$left,drop=FALSE]%*%Diagonal(x=lamlist$frac) +nbeta[,lamlist$right,drop=FALSE]%*%Diagonal(x=1-lamlist$frac)
     dimnames(nbeta)=list(vnames,paste(seq(along=s)))
   }
   if(type=="coefficients")return(nbeta)
